===============================
Firepit - STIX Columnar Storage
===============================


.. image:: https://img.shields.io/pypi/v/firepit.svg
        :target: https://pypi.python.org/pypi/firepit

.. image:: https://readthedocs.org/projects/firepit/badge/?version=latest
        :target: https://firepit.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Columnar storage for STIX 2.0 observations.


* Free software: Apache Software License 2.0
* Documentation: https://firepit.readthedocs.io.


Features
--------

* Transforms STIX Observation SDOs to a columnar format
* Inserts those transformed observations into SQL (currently sqlite3 and PostgreSQL)

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
